ChangeLog
=========

v0.6.0
----------------------

- Update to python3

v0.5.1
----------------------

- Update setup.py to fix marshmallow version <=0.7.0

v0.5.0
----------------------

- Removed dependency on RDKit. now using pinky for ECFP generation
- Refactored CLI to use click (http://click.pocoo.org/)
- Removed support for C6 algorithm
- JSON serialization now using marshmallow (http://marshmallow.readthedocs.org)

v0.0.2
----------------------

- Minor bug fixes

v0.0.1
----------------------

- Initial release
